@@ -15,11 +15,11 @@ Math::Symbolic::Custom::Collect - Collect up Math::Symbolic expressions
 
 =head1 VERSION
 
-Version 0.2
+Version 0.21
 
 =cut
 
-our $VERSION = '0.2';
+our $VERSION = '0.21';
 
 use Math::Symbolic qw(:all);
 use Math::Symbolic::Custom::Base;
@@ -422,6 +422,15 @@ sub cancel_down {
         }
     }
 
+    if ( (scalar(keys %n_terms) == 0) && (scalar(keys %d_terms) == 0) ) {
+        # do some tidying up of constant fractions with negative denominators
+        if ( $d_acc < 0 ) {
+            $n_acc *= -1;
+            $d_acc = abs($d_acc);
+            $did_some_cancellation = 1;
+        }
+    }
+
     $n_terms{constant_accumulator} = $n_acc;
     $d_terms{constant_accumulator} = $d_acc;
 
